@@ -1,4 +1,5 @@
 import os
+import json
 
 TEST_DIRECTORY = os.path.dirname(os.path.realpath(__file__))
 
@@ -21,3 +22,14 @@ PREFIX_LIST_TESTS = {
         "not": ["18.232.234.12/32"]
     }
 }
+
+TEST_ARTIFACT_CONTENT = json.dumps({
+    "hello": "world",
+    "foo": {
+        "bar": ["baz"]
+    }
+})
+
+TEST_ARTIFACT_MANIFEST_CONTENT = "eyJoZWxsbyI6ICJ3b3JsZCIsICJmb28iOiB7ImJhciI6IFsiYmF6Il19fQ=="  # noqa
+
+TEST_NONEXIST_APP = "__this_app_shouldn't_exist__"
\ No newline at end of file
